@@ -102,6 +102,10 @@ def main():
         default=default_args.pop("key_elapsed_time", "elapsed_time"),
         help="key name of the elapsed_time in the log file",
     )
+    parser.add_argument(
+        "--key-of-interest",
+        help="log key of interest",
+    )
     args = parser.parse_args()
 
     if args.version:
@@ -126,6 +130,7 @@ def main():
         key_epoch=args.key_epoch,
         key_iteration=args.key_iteration,
         key_elapsed_time=args.key_elapsed_time,
+        key_of_interest=args.key_of_interest,
     )
 
     if args.index is not None:
